@@ -1,6 +1,7 @@
+"""mp-pyrho package."""
+
 __author__ = """Jimmy Shen"""
 __email__ = "jmmshn@gmail.com"
-__version__ = "0.1.0"
 
 import os
 
@@ -10,5 +11,3 @@ try:
     __version__ = get_distribution(__name__).version
 except DistributionNotFound:
     pass
-
-test_files_dir = os.path.dirname(os.path.realpath(__file__)) + "/../../test_files"
