@@ -1,10 +1,10 @@
+"""Chang Density Objects: Periodic Grid + Lattice / Atoms."""
+
 from __future__ import annotations
 
+import math
 import warnings
 from dataclasses import dataclass
-
-"""Chang Density Objects: Periodic Grid + Lattice / Atoms"""
-import math
 from typing import Dict, List, Tuple, Union
 
 import numpy as np
@@ -18,18 +18,26 @@ from pymatgen.io.vasp import Chgcar, Poscar, VolumetricData
 from pyrho.pgrid import PGrid
 from pyrho.utils import get_sc_interp
 
+__all__ = ["ChargeDensity"]
+
 
 @dataclass
 class ChargeDensity(MSONable):
-    """
-    Defines a charge density with a PGrid object along with the atomic structure
+    """Charge density object.
+
+    Defines a charge density with a PGrid object along with the atomic structure.
+
+    Attributes
+    ----------
+    pgrids: Dict[str, PGrid]
+        Dictionaries whose values are periodic ``PGrid`` objects
+        representing some periodic scalar field (typically the keys are ``total`` and ``diff``
+        for spin-polarized charge densities.)
+    structure: Structure
+        The atomic structure for the electronic charge density.
+    normalization: str | None = "vasp"
+        The normalzation scheme (``vasp`` or ``None``)
 
-    Args:
-        grid_data: Volumetric data to read in
-        structure: Atomic structure corresponding to the charge density
-        normalization: the normalization scheme:
-            - 'vasp' sum of the data / number of grid points == number of electrons
-            - None/"none" no normalization
     """
 
     pgrids: Dict[str, PGrid]
@@ -37,9 +45,11 @@ class ChargeDensity(MSONable):
     normalization: str | None = "vasp"
 
     def __post_init__(self):
-        """Post initialization:
+        """Post initialization.
+
         Steps:
             - Make sure all the lattices are identical
+
         """
         lattices = [self.pgrids[key].lattice for key in self.pgrids.keys()]
         if not all(
@@ -58,6 +68,7 @@ class ChargeDensity(MSONable):
         -------
         dict[str, NDArray]:
             The normalized data in units of (electrons / Angstrom^3)
+
         """
         return {
             k: _normalize_data(
@@ -70,7 +81,7 @@ class ChargeDensity(MSONable):
 
     @property
     def grid_shape(self) -> Tuple[int, int, int]:
-        """Return the shape of the charge density"""
+        """Return the shape of the charge density."""
         return self.pgrids["total"].grid_shape
 
     @property
@@ -84,6 +95,7 @@ class ChargeDensity(MSONable):
         -------
         dict[str, PGrid]:
             The normalized pgrids in units of (electrons / Angstrom^3)
+
         """
         return {
             k: PGrid(
@@ -104,16 +116,26 @@ class ChargeDensity(MSONable):
 
     @classmethod
     def from_pmg(
-        cls, vdata: VolumetricData, data_key: str = "total", normalization: str = "vasp"
+        cls, vdata: VolumetricData, normalization: str = "vasp"
     ) -> "ChargeDensity":
-        """
+        """Get data from pymatgen object.
+
         Read a single key from the data field of a VolumetricData object
-        Args:
-            vdata: The volumetric data object
-            data_key: The key to read from in the data field
+
+        Parameters
+        ----------
+        vdata:
+            The volumetric data object
+        normalization:
+            The normalization scheme
+            - 'vasp' sum of the data / number of grid points == number of electrons
+            - None/"none" no normalization
+
+        Returns
+        -------
+        ChargeDensity:
+            The charge density object
 
-        Returns:
-            ChargeDensity object
         """
         pgrids = {
             k: PGrid(v, vdata.structure.lattice._matrix) for k, v in vdata.data.items()
@@ -123,9 +145,11 @@ class ChargeDensity(MSONable):
         )
 
     def reorient_axis(self) -> None:
-        """
-        Change the orientation of the lattice vector so that:
-        a points along the x-axis, b is in the xy-plane, c is in the positive-z halve of space
+        """Rorient the lattices.
+
+        Change the orientation of the lattice vector so that: ``a`` points along the x-axis, ``b`` is in the xy-plane,
+        ``c`` is in the positive-z halve of space
+
         """
         args: Tuple[float, float, float, float, float, float] = (
             self.structure.lattice.abc + self.structure.lattice.angles
@@ -143,6 +167,8 @@ class ChargeDensity(MSONable):
             The side length of the cube
         ngrid:
             Number of grid points in each direction
+        key:
+            The key to read from ``self.normalized_data``
 
         Returns
         -------
@@ -182,7 +208,6 @@ class ChargeDensity(MSONable):
             The transformed ChargeDensity object
 
         """
-
         # warning if the sc_mat is not integer valued
         if not np.allclose(np.round(sc_mat), sc_mat):
             warnings.warn(
@@ -224,12 +249,15 @@ class ChargeDensity(MSONable):
         )
 
     def to_Chgcar(self) -> Chgcar:
-        """Convert the charge density to a pymatgen.io.vasp.outputs.Chgcar object
+        """Convert the charge density to a ``pymatgen.io.vasp.outputs.Chgcar`` object.
 
-        Scale and convert each key in the pgrids dictionary and create a Chgcar object
+        Scale and convert each key in the pgrids dictionary and create a ``Chgcar`` object
+
+        Returns
+        -------
+        Chgcar:
+            The charge density object
 
-        Returns:
-            Chgcar: The charge density object
         """
         struct = self.structure.copy()
         data_dict = {}
@@ -256,6 +284,7 @@ class ChargeDensity(MSONable):
         Returns
         -------
             ChargeDensity: The ChargeDensity object
+
         """
         return cls.from_pmg(pmg_obj.from_file(filename))
 
@@ -276,6 +305,7 @@ class ChargeDensity(MSONable):
         Returns
         -------
             ChargeDensity: The ChargeDensity object
+
         """
         return cls.from_pmg(pmg_obj.from_hdf5(filename))
 
@@ -358,7 +388,8 @@ class ChargeDensity(MSONable):
 
 @deprecated
 def multiply_aug(data_aug: List[str], factor: int) -> List[str]:
-    """
+    """Update the data in the augmentation charge.
+
     The original idea here was to use to to speed up some vasp calculations for
     supercells by initializing the entire CHGCAR file.
     The current code does not deal with transformation of the Augementation charges after regridding.
@@ -367,11 +398,19 @@ def multiply_aug(data_aug: List[str], factor: int) -> List[str]:
     a real working implementation will require analysis of the PAW projection operators.
     However, even with such an implementation, the speed up will be minimal due to VASP's internal
     minimization algorithms.
-    Args:
-        data_aug: The original augmentation data from a CHGCAR
-        factor: The multiplication factor (some integer number of times it gets repeated)
-    Returns:
-        List of strings for each line of the Augmentation data.
+
+    Parameters
+    ----------
+    data_aug:
+        The original augmentation data from a CHGCAR
+    factor:
+        The multiplication factor (some integer number of times it gets repeated)
+
+    Returns
+    -------
+    List[str]:
+        Each line of the augmentation data.
+
     """
     res: List[str] = []
     cur_block: List[str] = []
@@ -401,7 +440,7 @@ def multiply_aug(data_aug: List[str], factor: int) -> List[str]:
 def _normalize_data(
     grid_data: npt.NDArray, lattice: Lattice, normalization: str | None = "vasp"
 ) -> npt.NDArray:
-    """Normalize the data to the number of electrons
+    """Normalize the data to the number of electrons.
 
     Since different codes use different normalization methods for
     volumetric data we should convert them to the same units (electrons / Angstrom^3)
@@ -427,6 +466,7 @@ def _normalize_data(
     -------
     NDArray:
         The normalized grid data
+
     """
     if normalization is None or normalization[0].lower() == "n":
         return grid_data
@@ -439,7 +479,7 @@ def _normalize_data(
 def _scaled_data(
     grid_data: npt.NDArray, lattice: Lattice, normalization: str | None = "vasp"
 ) -> npt.NDArray:
-    """Undo the normalization of the data
+    """Undo the normalization of the data.
 
     Parameters
     ----------
@@ -453,7 +493,8 @@ def _scaled_data(
     Returns
     -------
     NDArray:
-        The unnormalized grid data
+        The un-normalized grid data
+
     """
     if normalization is None or normalization[0].lower() == "n":
         return grid_data
